.. _support-section:

*******
Support
*******

All support issues can be submitted to our `issue tracker <https://bitbucket.org/jairhul/pybdsim/issues?status=new&status=open>`_


.. _feature-request:

Feature Request
---------------

Feature requests or proposals can be submitted to the issue tracker - select the issue
type as proposal or enhancement.. 

Please have a look at the existing `list of proposals <https://bitbucket.org/jairhul/pybdsim/issues?status=new&status=open&status=on+hold&kind=proposal&kind=enhancement>`_
before submitting a new one.
